#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Only
version:              0.1
visibility:           public
id:                   Only-0.1-DItEcvi68ww8z5TVixWVcj
key:                  Only-0.1-DItEcvi68ww8z5TVixWVcj
license:              BSD-3-Clause
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel
synopsis:             The 1-tuple type or single-value "collection"
description:
    This package provides the canonical anonymous 1-tuple type missing from Haskell for attaching typeclass instances.

category:             Data
abi:                  7823aa641f182f8ce707e26bcd31a12b
exposed:              True
exposed-modules:      Data.Tuple.Only
import-dirs:          /usr/lib/ghc-9.6.6/site-local/Only-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Only-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Only-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-only
hs-libraries:         HSOnly-0.1-DItEcvi68ww8z5TVixWVcj
depends:              base-4.18.2.1 deepseq-1.4.8.1
haddock-interfaces:   /usr/share/doc/haskell-only/html/Only.haddock
haddock-html:         /usr/share/doc/haskell-only/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

